@@ -689,7 +689,9 @@ JOIN information_schema.index_columns AS ic
 WHERE
     i.table_name="{table_name}"
     AND i.index_type != 'PRIMARY_KEY'
+    AND i.spanner_is_managed = FALSE
 GROUP BY i.index_name, i.is_unique
+ORDER BY i.index_name
 """.format(
             table_name=table_name
         )
@@ -871,7 +873,12 @@ SELECT ccu.CONSTRAINT_NAME, ccu.COLUMN_NAME
 FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS AS tc
 JOIN INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE AS ccu
     ON ccu.CONSTRAINT_NAME = tc.CONSTRAINT_NAME
-WHERE tc.TABLE_NAME="{table_name}" AND tc.CONSTRAINT_TYPE = "UNIQUE"
+LEFT JOIN INFORMATION_SCHEMA.REFERENTIAL_CONSTRAINTS AS rc
+    on tc.CONSTRAINT_NAME = rc.CONSTRAINT_NAME
+WHERE
+    tc.TABLE_NAME="{table_name}"
+    AND tc.CONSTRAINT_TYPE = "UNIQUE"
+    AND rc.CONSTRAINT_NAME IS NOT NULL
 """.format(
             table_name=table_name
         )
@@ -1015,7 +1022,7 @@ LIMIT 1
 
 
 # Alembic ALTER operation override
-@compiles(ColumnNullable, "spanner")
+@compiles(ColumnNullable, "spanner+spanner")
 def visit_column_nullable(
     element: "ColumnNullable", compiler: "SpannerDDLCompiler", **kw
 ) -> str:
@@ -1028,7 +1035,7 @@ def visit_column_nullable(
 
 
 # Alembic ALTER operation override
-@compiles(ColumnType, "spanner")
+@compiles(ColumnType, "spanner+spanner")
 def visit_column_type(
     element: "ColumnType", compiler: "SpannerDDLCompiler", **kw
 ) -> str:
